<template>
  <a-card :bordered='false'>

    <!-- 查询区域 -->
    <div class='table-page-search-wrapper'>
      <a-form layout='inline' @keyup.enter.native='search'>
        <a-row :gutter='24'>
          <a-col :md='8' :sm='8'>
            <a-form-item label='时间区间'>
              <a-range-picker
                v-model='queryParam.dateRange'
                format='YYYY-MM-DD'
                :placeholder="['开始时间', '结束时间']"
                @change='onDateChange'>
              </a-range-picker>
            </a-form-item>
          </a-col>
          <a-col :md='8' :sm='8'>
            <a-form-item label='仪器名称' :labelCol='{span: 5}' :wrapperCol='{span: 18, offset: 1}'>

              <a-select placeholder='请选择仪器名称' v-model='queryParam.instrumentId'>
                <a-select-option v-for='(item,index) in equList' :key='index' :value='item.id'>
                  {{ item.name }}
                </a-select-option>
              </a-select>

            </a-form-item>
          </a-col>
<!--          <a-col :md='8' :sm='8'>
            <a-form-item label='使用类型' :labelCol='{span: 5}' :wrapperCol='{span: 18, offset: 1}'>

              <a-select placeholder='请选择使用类型' v-model='queryParam.useType'>
                <a-select-option :value='1'>
                  临时使用
                </a-select-option>
                <a-select-option :value='2'>
                  预约使用
                </a-select-option>
              </a-select>

            </a-form-item>
          </a-col>
          <a-col :md='8' :sm='8'>
            <a-form-item label='使用人' :labelCol='{span: 5}' :wrapperCol='{span: 18, offset: 1}'>
              <a-select placeholder='请选择使用人' v-model='queryParam.createBy'>
                <a-select-option v-for='(item,index) in userList' :key='index' :value='item.username'>
                  {{ item.realname }}
                </a-select-option>
              </a-select>
            </a-form-item>
          </a-col>-->
          <span style='float: left;overflow: hidden;' class='table-page-search-submitButtons'>
            <a-col :md='8' :sm='24'>
              <a-button type='primary' @click='search'>查询</a-button>
              <a-button style='margin-left: 8px' @click='searchReset'>重置</a-button>
            </a-col>
          </span>
        </a-row>
      </a-form>
    </div>
    <!-- 查询区域-END -->

    <!-- 操作按钮区域 -->
    <div class='table-operator'>
      <a-button type='primary' icon='download' @click="handleExportXls('点检统计')">导出</a-button>
    </div>

    <!-- table区域-begin -->
    <div>
      <div class='ant-alert ant-alert-info' style='margin-bottom: 16px;'>
        <i class='anticon anticon-info-circle ant-alert-icon'></i> 已选择 <a
        style='font-weight: 600'>{{ selectedRowKeys.length }}</a>项
        <a style='margin-left: 24px' @click='onClearSelected'>清空</a>
<!--        <span style='float:right;'>
                  <a-popover title='自定义列' trigger='click' placement='leftBottom'>
                    <template slot='content'>
                        <a-radio-group v-model='selectUnit'  @change="onRadioChange">
                        <a-radio :style='radioStyle' :value='0'>
                          小时
                        </a-radio>
                        <a-radio :style='radioStyle' :value='1'>
                          分
                        </a-radio>
                        <a-radio :style='radioStyle' :value='2'>
                          秒
                        </a-radio>
                      </a-radio-group>
                    </template>
                    <a><a-icon type='setting' />设置</a>
                  </a-popover>
                </span>-->
      </div>

      <a-table
        ref='table'
        size='middle'
        :scroll='{x:true}'
        bordered
        rowKey='id'
        :columns='columns'
        :dataSource='dataSource'
        :pagination='ipagination'
        :loading='loading'
        :rowSelection='{selectedRowKeys: selectedRowKeys, onChange: onSelectChange}'
        class='j-table-force-nowrap'
        @change='handleTableChange'>
        <template slot="useTime" slot-scope="text,record">
          <span> {{text + unit[selectUnit]}}   </span>
        </template>

      </a-table>
    </div>
    <!-- table区域-end -->

    <!-- 图表区域-begin -->
    <div>
      <a-tabs type='card'>
        <a-tab-pane key='1' tab='柱状图'>
          <div id='bar31' style='width: 100%;height: 400px'></div>
        </a-tab-pane>
        <a-tab-pane key='2' tab='折线图' forceRender>
          <div id='line32' style='width: 100%;height: 400px'></div>
        </a-tab-pane>
      </a-tabs>


    </div>
    <!-- 图表区域-end -->
  </a-card>
</template>

<script>
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import { getAction } from '@api/manage'
import { getLastWeek,getLastMonth } from '@/utils/util'
import moment from 'moment'
import * as echarts from 'echarts'

export default {
  name: 'SpotStat',
  mixins: [JeecgListMixin],
  data(){
    return{
      disableMixinCreated: true,
      // 表头
      columns: [
        {
          title: '#',
          dataIndex: '',
          key: 'rowIndex',
          width: 60,
          align: 'center',
          customRender: function(t, r, index) {
            return parseInt(index) + 1
          }
        },
        {
          title: '仪器名称',
          align: 'center',
          dataIndex: 'instrument'
        },
        {
          title: '点检总次数',
          align: 'center',
          dataIndex: 'total'

        },
        {
          title: '点检正常',
          align: 'center',
          dataIndex: 'ok',

        },
        {
          title: '点检异常',
          align: 'center',
          dataIndex: 'un'
        },

      ],
      equList: [],
      userList: [],
      dateFormat: 'YYYY-MM-DD',
      selectUnit: 0,
      unit: ['小时','分钟','秒'],
      radioStyle: {
        display: 'block',
        height: '30px',
        lineHeight: '30px'
      },
      url: {
        list: '/lims/stat/spot',
        exportXlsUrl: '/lims/stat/exportSpotXls',
      }
    }
  },
  created() {
    this.queryEquList()
    //默认查询上周数据
     let lastWeek = getLastMonth(0)
     this.initQuery(lastWeek.start, lastWeek.end)

  },
  methods:{
    search() {
      let params = Object.assign({}, this.queryParam)
      if (params.dateRange) {
        delete params.dateRange //范围参数不传递后台
      }
      this.loadData(params)
    },
    searchReset() {
      this.queryParam = {}
      //默认查询上周数据
      let lastWeek = getLastMonth(0)
      this.initQuery(lastWeek.start, lastWeek.end)
    },
    initQuery(start, end) {
      this.queryParam.createTime_begin = start
      this.queryParam.createTime_end = end
      this.queryParam.dateRange = [
        moment(start, this.dateFormat),
        moment(end, this.dateFormat)
      ]
      let params = Object.assign({}, this.queryParam)
      if (params.dateRange) {
        delete params.dateRange //范围参数不传递后台
      }
      this.$forceUpdate()
      this.loadData(params)
    },
    onDateChange: function(value, dateString) {
      this.queryParam.createTime_begin = dateString[0]
      this.queryParam.createTime_end = dateString[1]
      this.$forceUpdate()
    },
    onRadioChange(e) {
      console.log('radio checked', e.target.value);
      this.selectUnit =  e.target.value

      //重新加载数据
      let params = Object.assign({}, this.queryParam)
      if (params.dateRange) {
        delete params.dateRange //范围参数不传递后台
      }
      this.loadData(params)

    },
    loadData(params) {
      this.loading = true
      getAction(this.url.list, params).then((res) => {
        this.loading = false
        if (res.success) {
          this.dataSource = res.result
          this.createData()
        }
      })
    },
    createData() {
      let xAxis = []
      let data1 = []
      let data2 = []
      let data3 = []
      this.dataSource.forEach((item, index, arr) => {
        xAxis.push(item.instrument)
        data1.push(item.total)
        data2.push(item.ok)
        data3.push(item.un)
      })

      this.initBarChart(xAxis, data1,data2,data3)
      this.initLineChart(xAxis, data1,data2,data3)
      // this.initPieChart(xAxis, data)
    },
    //查询设备列表
    queryEquList() {
      getAction('/limsInstrument/list').then(res => {
        if (res.success) {
          this.equList = res.result.records
        }

      })
    },
    initBarChart(xAxis, data1,data2,data3) {
      var chartDom = document.getElementById('bar31')
      var myChart = echarts.init(chartDom)
      var option

      option = {
        tooltip: {
          trigger: 'axis',
          axisPointer: {
            type: 'shadow'
          }
        },
        legend: {
          center: 'center'
        },
        toolbox: {
          show: true,
          feature: {
            saveAsImage: {
              show: true,
              name: '点检统计-柱状图'
            }
          }
        },
        xAxis: {
          type: 'category',
          data: xAxis,
          name: '仪器',
          axisLabel: { interval: 0, rotate: 30 }
        },
        yAxis: {
          type: 'value',
          name: '点检次数'
        },
        series: [
          {
            name:'点检总次数',
            barGap: 0,
            data: data1,
            type: 'bar',
            label: {
              show: true,
              position: 'top',
              valueAnimation: true
            }
          },
          {
            name:'点检成功',
            barGap: 0,
            data: data2,
            type: 'bar',
            label: {
              show: true,
              position: 'top',
              valueAnimation: true
            }
          },
          {
            name:'点检异常',
            barGap: 0,
            data: data3,
            type: 'bar',
            label: {
              show: true,
              position: 'top',
              valueAnimation: true
            }
          },
        ]
      }

      option && myChart.setOption(option)

    },
    initLineChart(xAxis,  data1,data2,data3) {
      var chartDom = document.getElementById('line32')
      var myChart = echarts.init(chartDom)
      var option

      option = {
        tooltip: {
          trigger: 'axis',
          axisPointer: {
            type: 'shadow'
          }
        },
        legend: {
          center: 'center'
        },
        toolbox: {
          show: true,
          feature: {
            saveAsImage: {
              show: true,
              name: '点检统计-折线图'
            }
          }
        },
        xAxis: {
          type: 'category',
          data: xAxis,
          name: '仪器',
          axisLabel: { interval: 0, rotate: 30 }
        },
        yAxis: {
          type: 'value',
          name: '点检次数'
        },
        series: [
          {
            name:'点检总次数',
            data: data1,
            type: 'line',
            label: {
              show: true,
              position: 'top',
              valueAnimation: true
            }
          },
          {
            name:'点检成功',
            data: data2,
            type: 'line',
            label: {
              show: true,
              position: 'top',
              valueAnimation: true
            }
          },
          {
            name:'点检异常',
            data: data3,
            type: 'line',
            label: {
              show: true,
              position: 'top',
              valueAnimation: true
            }
          },
        ]
      }

      option && myChart.setOption(option)

    },

  }
}
</script>

<style scoped>

</style>